@@ -1,10 +1,12 @@
 from pathlib import Path
 
 from arkive.core.drive import Drive
+from arkive.utility.sanitize import sanitize_label
 
 
 def show_music_file(file: dict):
-    return [file['artist'], file['album'], file['title']]
+    file_tags = (file['artist'], file['album'], file['title'])
+    return [sanitize_label(str(tag)) for tag in file_tags]
 
 
 def show_music_collection(drive: Drive, origin: Path):
